==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/PutChannelPolicyRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class PutChannelPolicyRequest(
    channelName: __string,
    policy: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.PutChannelPolicyRequest = {
    import PutChannelPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.PutChannelPolicyRequest
      .builder()
      .channelName(__string.unwrap(channelName): java.lang.String)
      .policy(__string.unwrap(policy): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.PutChannelPolicyRequest.ReadOnly =
    zio.aws.mediatailor.model.PutChannelPolicyRequest.wrap(buildAwsValue())
}
object PutChannelPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.PutChannelPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.PutChannelPolicyRequest =
      zio.aws.mediatailor.model.PutChannelPolicyRequest(channelName, policy)
    def channelName: __string
    def policy: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
    def getPolicy: ZIO[Any, Nothing, __string] = ZIO.succeed(policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.PutChannelPolicyRequest
  ) extends zio.aws.mediatailor.model.PutChannelPolicyRequest.ReadOnly {
    override val channelName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.channelName())
    override val policy: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.policy())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.PutChannelPolicyRequest
  ): zio.aws.mediatailor.model.PutChannelPolicyRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediatailor_3-5.17.194.1-sources.jar: zio/aws/mediatailor/model/PutChannelPolicyRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class PutChannelPolicyRequest(
    channelName: __string,
    policy: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.PutChannelPolicyRequest = {
    import PutChannelPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.PutChannelPolicyRequest
      .builder()
      .channelName(channelName: java.lang.String)
      .policy(policy: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.PutChannelPolicyRequest.ReadOnly =
    zio.aws.mediatailor.model.PutChannelPolicyRequest.wrap(buildAwsValue())
}
object PutChannelPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.PutChannelPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.PutChannelPolicyRequest =
      zio.aws.mediatailor.model.PutChannelPolicyRequest(channelName, policy)
    def channelName: __string
    def policy: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
    def getPolicy: ZIO[Any, Nothing, __string] = ZIO.succeed(policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.PutChannelPolicyRequest
  ) extends zio.aws.mediatailor.model.PutChannelPolicyRequest.ReadOnly {
    override val channelName: __string = impl.channelName(): __string
    override val policy: __string = impl.policy(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.PutChannelPolicyRequest
  ): zio.aws.mediatailor.model.PutChannelPolicyRequest.ReadOnly = new Wrapper(
    impl
  )
}
